@@ -5,7 +5,7 @@ def check_result(result_dict: dict, result_check_dict: dict):
     for key, value in result_check_dict.items():
         if result_dict.get(key) != value:
             raise APIAssertException(
-                "value should be {right_value} but value is {wrong_value}".format(
+                "value should be {right_value} but value was {wrong_value}".format(
                     right_value=result_dict.get(key), wrong_value=value
                 )
             )
